<?php /*

**************************************************************************

Plugin Name:  Clean Archives Reloaded
Plugin URI:   http://www.viper007bond.com/wordpress-plugins/clean-archives-reloaded/
Description:  A slick, Javascript-enhanced post archive list generator for WordPress 2.5+.
Version:      3.0.0
Author:       Viper007Bond
Author URI:   http://www.viper007bond.com/

**************************************************************************

Copyright (C) 2008 Viper007Bond

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

**************************************************************************/

class CleanArchivesReloaded {

	# Configuration has been moved to the new options page at Settings -> Clean Archives.
	# You can also set the configuration via the shortcode tag.


	// Class initialization
	function CleanArchivesReloaded() {
		if ( !function_exists('add_shortcode') ) return;

		// Load up the localization file if we're using WordPress in a different language
		// Place it in this plugin's folder and name it "car-[value in wp-config].mo"
		load_plugin_textdomain( 'car', '/wp-content/plugins/clean-archives-reloaded' );

		// Make sure all the plugin options have defaults set
		if ( FALSE === get_option('car_usejs') )      add_option( 'car_usejs', 1 );
		if ( FALSE === get_option('car_monthorder') ) add_option( 'car_monthorder', 'new' );
		if ( FALSE === get_option('car_postorder') )  add_option( 'car_postorder', 'old' );

		// Register all the hooks
		add_action( 'admin_menu', array(&$this, 'AddAdminMenu') );
		add_shortcode( 'cleanarchivesreloaded' , array(&$this, 'PostList') );
		add_shortcode( 'cartotalposts' , array(&$this, 'PostCount') );

		// Enqueue the Javascript and the little CSS to be outputted
		add_action( 'wp_head', array(&$this, 'OutputCSSJavascript') );
		wp_enqueue_script( 'jquery' );

		// For users with a persistent object caching plugin installed, we need to dump the cache in some cases
		add_action( 'save_post', array(&$this, 'DeleteCache') );
		add_action( 'edit_post', array(&$this, 'DeleteCache') );
		add_action( 'delete_post', array(&$this, 'DeleteCache') );
	}


	// Register the admin menu
	function AddAdminMenu() {
		add_options_page( __('Clean Archives Reloaded', 'car'), __('Clean Archives', 'car'), 'manage_options', 'clean-archives-reloaded', array(&$this, 'OptionsPage') );
	}


	// The options page for this plugin
	function OptionsPage() { ?>

<div class="wrap">
	<h2><?php _e('Clean Archives Reloaded', 'car'); ?></h2>

	<form method="post" action="options.php">
<?php wp_nonce_field('update-options') ?>

	<table class="form-table">
	<tr>
		<th scope="row" colspan="2" class="th-full">
			<label for="car_usejs">
				<input name="car_usejs" type="checkbox" id="car_usejs" value="1" <?php checked('1', get_option('car_usejs')); ?> />
				<?php _e('Use Javascript to make the months collapsible', 'car'); ?>
			</label>
		</th>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Month Ordering', 'car'); ?></th>
		<td>
			<p>
				<label><input name="car_monthorder" type="radio" value="new" <?php checked('new', get_option('car_monthorder')); ?> /> <?php _e('Show newest months first', 'car'); ?></label><br />
				<label><input name="car_monthorder" type="radio" value="old" <?php checked('old', get_option('car_monthorder')); ?> /> <?php _e('Show oldest months first', 'car'); ?></label>
			</p>
		</td>
	</tr>
	<tr valign="top">
		<th scope="row"><?php _e('Post Ordering', 'car'); ?></th>
		<td>
			<p><?php _e('Within individual months...', 'car'); ?></p>
			<p>
				<label><input name="car_postorder" type="radio" value="new" <?php checked('new', get_option('car_postorder')); ?> /> <?php _e('Show newest posts first', 'car'); ?></label><br />
				<label><input name="car_postorder" type="radio" value="old" <?php checked('old', get_option('car_postorder')); ?> /> <?php _e('Show oldest posts first', 'car'); ?></label>
			</p>
		</td>
	</tr>
	</table>

	<p class="submit">
		<input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
		<input type="hidden" name="action" value="update" />
		<input type="hidden" name="page_options" value="car_usejs,car_monthorder,car_postorder" />
	</p>

	</form>
</div>

<?php
	}


	// Output a little helper CSS and the Javascript for the plugin
	// Based on code from http://www.learningjquery.com/2007/03/accordion-madness
	function OutputCSSJavascript() { ?>

	<!-- Clean Archives Reloaded v3.0.0 | http://www.viper007bond.com/wordpress-plugins/clean-archives-reloaded/ -->
	<style type="text/css">.car-collapse .car-yearmonth { cursor: s-resize; } </style>
	<script type="text/javascript">
		//<![CDATA[
			jQuery(document).ready(function() {
				jQuery('.car-collapse').children('ul').children('li').children('ul').hide();
				jQuery('.car-firstmonth').show();
				jQuery('.car-collapse').children('ul').children('li').children('.car-yearmonth').click(function() {
					jQuery(this).next('ul').slideToggle('fast');
				});
				jQuery('.car-toggler').click(function() {
					if ( '<?php echo js_escape( __('Expand All', 'car') ); ?>' == jQuery(this).text() ) {
						jQuery(this).parent('.car-container').children('ul').children('li').children('ul').show();
						jQuery(this).text('<?php echo js_escape( __('Collapse All', 'car') ); ?>');
					}
					else {
						jQuery(this).parent('.car-container').children('ul').children('li').children('ul').hide();
						jQuery(this).text('<?php echo js_escape( __('Expand All', 'car') ); ?>');
					}
					return false;
				});
			});
		//]]>
	</script>

<?php
	}


	// Grab all posts and filter them into an array
	function GetPosts() {
		// If we have a cached copy of the filtered posts array, use that instead
		if ( $posts = wp_cache_get( 'posts', 'clean-archives-reloaded' ) )
			return $posts;

		// Get a simple array of all posts
		$rawposts = get_posts( 'numberposts=0' );

		// Loop through each post and sort it into a structured array
		foreach( $rawposts as $key => $post ) {
			$posts[ mysql2date( 'Y.m', $post->post_date ) ][ mysql2date( 'U', $post->post_date ) ] = $post;

			unset( $rawposts[$key] ); // Try and free up memory for users with lots of posts and poor server configs
		}
		$rawposts = NULL; // More memory cleanup

		// Store the results into the WordPress cache
		wp_cache_set( 'posts', $posts, 'clean-archives-reloaded' );

		return $posts;
	}


	// Generates the HTML output based on $atts array from the shortcode
	function PostList( $atts = array() ) {
		global $wp_locale;

		// Set any missing $atts items to the defaults
		$atts = shortcode_atts(array(
			'usejs'      => get_option('car_usejs'),
			'monthorder' => get_option('car_monthorder'),
			'postorder'  => get_option('car_postorder'),
		), $atts);

		// Get the big array of all posts
		$posts = $this->GetPosts();

		// Sort the posts based on $atts
		foreach( $posts as $key => $month ) {
			( 'old' == $atts['postorder'] ) ? ksort( $month ) : krsort( $month );
			$posts[$key] = $month;
			unset($month);
		}
		( 'old' == $atts['monthorder'] ) ? ksort( $posts ) : krsort( $posts );


		// Generate the HTML
		$html = '<div class="car-container';
		if ( 1 == $atts['usejs'] ) $html .= ' car-collapse';
		$html .= '">'. "\n";

		if ( 1 == $atts['usejs'] ) $html .= '<a href="#" class="car-toggler">' . __('Expand All', 'car') . "</a>\n\n";

		$html .= '<ul class="car-list">' . "\n";

		$firstmonth = TRUE;
		foreach( $posts as $yearmonth => $posts ) {
			list( $year, $month ) = explode( '.', $yearmonth );

			$firstpost = TRUE;
			foreach( $posts as $post ) {
				if ( TRUE == $firstpost ) {
					$html .= '	<li><span class="car-yearmonth">' . sprintf( __('%1$s %2$d'), $wp_locale->get_month($month), $year ) . ' <span title="' . __('Post Count', 'car') . '">(' . count($posts) . ")</span></span>\n		<ul class='car-monthlisting";
					if ( TRUE == $firstmonth ) {
						$html .= ' car-firstmonth';
						$firstmonth = FALSE;
					}
					$html .= "'>\n";
					$firstpost = FALSE;
				}

				$html .= '			<li>' .  mysql2date( 'd', $post->post_date ) . ': <a href="' . get_permalink( $post->ID ) . '">' . get_the_title( $post->ID ) . '</a>';

				// Unless comments are closed and there are no comments, show the comment count
				if ( ( 0 != $post->comment_count || 'closed' != $post->comment_status ) && empty($post->post_password) ) $html .= ' <span title="' . __('Comment Count', 'car') . '">(' . $post->comment_count . ')</span>';

				$html .= "</li>\n";
			}

			$html .= "		</ul>\n	</li>\n";
		}

		$html .= "</ul>\n</div>\n";

		return $html;
	}


	// Returns the total number of posts
	function PostCount() {
		$num_posts = wp_count_posts( 'post' );
		return number_format_i18n( $num_posts->publish );
	}


	// Deletes the cached filtered posts array for users using a persistent caching plugin
	function DeleteCache() {
		wp_cache_delete( 'posts', 'clean-archives-reloaded' );
	}
}

// Start this plugin once all other plugins are fully loaded
add_action( 'plugins_loaded', create_function( '', 'global $CleanArchivesReloaded; $CleanArchivesReloaded = new CleanArchivesReloaded();' ) );


// Some backwards compatibility wrapper functions
function car_total_posts() {
	global $CleanArchivesReloaded;
	return $CleanArchivesReloaded->PostCount();
}
function clean_archives_reloaded() {
	global $CleanArchivesReloaded;
	echo $CleanArchivesReloaded->PostList();
}
function car_regenerate() {
	return FALSE;
}

?>